inbound property

  1. @override
Stream<String> get inbound
override

Frames as they arrive.

Closing this stream, or letting an error reach it, is how the link reports that it is gone.

Implementation

@override
Stream<String> get inbound => _inbound.stream;